// pages/home/home.js

import {
  ApiHome,
  ApiWXCode,
  ApiGetRoleType
} from '../../http/api'
import {
  wxGet,
  HOST
} from '../../http/network'

const app = getApp()

Page({

  /**
   * 页面的初始数据
   */
  data: {
    headTop: 0,
    height: 0,
    top: 0,
    data: null,
    roleType: -1,
    noticeIndex: 1,
    showPoster: false,
    base64Data: null,
    canvas: null,
    visible: false
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {

    const recommendUserId = options.scene
    if(recommendUserId){
      const p = wx.getStorageSync('recommendUserId')
      if(!p){
        wx.setStorageSync('recommendUserId', recommendUserId)
      }
    }

    const {
      height,
      top
    } = wx.getMenuButtonBoundingClientRect()
    this.setData({
      headTop: top + height + 10,
      height,
      top
    })
    this.getData()
  },
  onShow() {
    wxGet(ApiGetRoleType).then(res => {
      this.setData({
        roleType: res.data
      })
      app.globalData.roleType = res.data
    })
  },
  getData() {
    wxGet(ApiHome).then(res => {
      this.setData({
        data: res.data
      })
    })
  },
  searchAction() {
    wx.navigateTo({
      url: '/pages/search/index',
    })
  },
  noticeChange(e) {
    this.setData({
      noticeIndex: e.detail.current + 1
    })
  },
  linkAction(e){
    let index = e.currentTarget.dataset.index
    let type = this.data.data.bannerList[index].type
    let mpArticle = this.data.data.bannerList[index].mpArticle
    if(type == 2 && mpArticle.length > 0){
      wx.navigateTo({
        url: '/pages/web/web-page?url=' + encodeURIComponent(mpArticle),
      })
    }
  },
  serviceItemClick(e) {
    let index = e.currentTarget.dataset.index
    let p1 = index.split("-")[0]
    let p2 = index.split("-")[1]
    let id = this.data.data.serviceList[p1].children[p2].id
    let serviceName = this.data.data.serviceList[p1].children[p2].serviceName
    wx.navigateTo({
      url: `../service/service-detail?id=${id}&serviceName=${serviceName}`
    })
  },
  serviceCateClick(e) {
    let id = e.currentTarget.dataset.id
    app.globalData.cateId = id
    wx.switchTab({
      url: '/pages/service/service',
    })
  },
  getQrcode() {
    wx.showLoading({
      title: '生成中',
    })
    let url = HOST + ApiWXCode
    let param = {
      "path": "pages/home/home",
      "scene": app.globalData.userId,
      "width": 0
    }
    let that = this

    wx.request({
      url: url,
      method: 'POST',
      data: param,
      header: {
        'Authorization': app.globalData.token
      },
      success: function (res) {
        if (res.data.code == 200) {
          let base64data = 'data:image/png;base64,' + res.data.data
          const [, format, bodyData] = /data:image\/(\w+);base64,(.*)/.exec(base64data) || []
          if (!format) {
            wx.showToast({
              icon: "none",
              title: '生成失败',
              duration: 1000,
            })
          } else {
            const buffer = wx.base64ToArrayBuffer(bodyData);
            let fsm = wx.getFileSystemManager()
            wx.hideLoading()
            fsm.writeFile({
              filePath: `${wx.env.USER_DATA_PATH}/qrcode.png`,
              encoding: 'binary',
              data: buffer,
              success: res => {
                that.setData({
                  base64Data: `${wx.env.USER_DATA_PATH}/qrcode.png`,
                  showPoster: true
                })
                that.saveImageToPhotosAlbum()
              }
            })
          }
        }else{
          wx.showToast({
            icon: "none",
            title: '生成失败',
            duration: 1000,
          })
        }
      },
      fail: function (e) {
        console.log(e)
        wx.hideLoading()
      }
    })
  },

  saveImageToPhotosAlbum() {
    let that = this
    const query = wx.createSelectorQuery()
    query.select('#share')
      .fields({
        node: true,
        size: true
      })
      .exec(async (res) => {
        const canvas = res[0].node
        that.setData({
          canvas: canvas
        })
        const ctx = canvas.getContext('2d')
        const dpr = wx.getSystemInfoSync().pixelRatio
        canvas.width = res[0].width * dpr
        canvas.height = res[0].height * dpr
        ctx.scale(dpr, dpr)
        // 创建一个图片
        const image = canvas.createImage()

        let width = canvas.width / dpr
        let height = canvas.height / dpr

        let topHeight = height * 920 / 1180

        await new Promise(resolve => {
          image.onload = resolve
          image.src = "/assets/main/poster-center.png"
        })
        ctx.drawImage(image, 0, 0, width, height)

        // 创建一个图片
        const icon = canvas.createImage()
        await new Promise(resolve => {
          icon.onload = resolve
          icon.src = that.data.base64Data
        })
        // 开始创建一个路径
        ctx.beginPath()
        // 画一个圆形裁剪区域
        ctx.arc(width/2, topHeight + 30 + 40, 40, 0, Math.PI * 2, false)
        // 裁剪
        ctx.clip()
        ctx.drawImage(icon, width/2 - 40, topHeight + 30, 80, 80)
      })
  },
  saveAction(){
    // 将生成的canvas图片，转为真实图片
    wx.canvasToTempFilePath({
      x: 0,
      y: 0,
      canvas: this.data.canvas,
      success: function (res) {
       wx.saveImageToPhotosAlbum({
         filePath: res.tempFilePath,
         success: (rest) => {
           wx.showToast({
             title: '保存成功',
             duration: 1000,
           });
         }
     });
      },
      fail: function (res) {
       console.log(res)
      }
    })
  },
   // 取消
   cancelAction() {
    this.setData({
      showPoster: false
    })
  },
  showConcat(){
    this.setData({
      visible: true
    })
  }
})